aboutsummaryrefslogtreecommitdiff
path: root/src/cmd/vendor/github.com/google/pprof/driver
diff options
context:
space:
mode:
authorDmitri Shuralyov <dmitshur@golang.org>2024-02-15 23:59:52 -0500
committerGopher Robot <gobot@golang.org>2024-02-16 15:19:53 +0000
commit63dd79c07b0026b58f421a5273c41e705ccb73d1 (patch)
tree78ae03458e1b1f1ea8e3dde24533f6b4eb1af94e /src/cmd/vendor/github.com/google/pprof/driver
parent3b51581261704bfc3e6feeb29b6d2588b163777d (diff)
downloadgo-63dd79c07b0026b58f421a5273c41e705ccb73d1.tar.xz
cmd/pprof: update vendored github.com/google/pprof
Pull in the latest published version of github.com/google/pprof as part of the continuous process of keeping Go's dependencies up to date. Done with: go get github.com/google/pprof go mod tidy go mod vendor For #36905. Fixes #65741. Change-Id: Ice7b085c03ff69be97929cbe47bfd91954907529 Cq-Include-Trybots: luci.golang.try:gotip-linux-amd64-longtest Reviewed-on: https://go-review.googlesource.com/c/go/+/564636 Reviewed-by: Dmitri Shuralyov <dmitshur@google.com> LUCI-TryBot-Result: Go LUCI <golang-scoped@luci-project-accounts.iam.gserviceaccount.com> Auto-Submit: Dmitri Shuralyov <dmitshur@golang.org> Reviewed-by: Cherry Mui <cherryyz@google.com>
Diffstat (limited to 'src/cmd/vendor/github.com/google/pprof/driver')
-rw-r--r--src/cmd/vendor/github.com/google/pprof/driver/driver.go7
1 files changed, 4 insertions, 3 deletions
diff --git a/src/cmd/vendor/github.com/google/pprof/driver/driver.go b/src/cmd/vendor/github.com/google/pprof/driver/driver.go
index 5a8222f70a..d5860036c3 100644
--- a/src/cmd/vendor/github.com/google/pprof/driver/driver.go
+++ b/src/cmd/vendor/github.com/google/pprof/driver/driver.go
@@ -186,9 +186,10 @@ type ObjFile interface {
// A Frame describes a single line in a source file.
type Frame struct {
- Func string // name of function
- File string // source file name
- Line int // line in file
+ Func string // name of function
+ File string // source file name
+ Line int // line in file
+ Column int // column in file
}
// A Sym describes a single symbol in an object file.